#!/usr/bin/perl
# groupCalcPct.pl script 
#	calculates max, pct95 and pct98 values from metric list
#	usually called from wrapping script groupPctReport.sh
#	parameters:	input csv file, number of ports, output file name
# 	e.g. perl  groupCalcPct.pl temp.csv 13 report.csv
#
# Prerequisites: tested with perl 5.18
#
# DISCLAIMER
# This script is provided AS IS and no warranties are provided or made.  
# For more information refer to http://www.ca.com/us/legal/terms-for-user-sites.aspx


use strict;

my $num_args = $#ARGV + 1;
if ($num_args != 3) {
	  print "\nUsage: getPct.pl infile port_count outfile\n";
	  exit;
}
my $filename=$ARGV[0];
my $count=$ARGV[1];
my $outfilename=$ARGV[2];

my $groupname;
my $bpsOut;
my $bpsIn;
my $rc;
my @bpsInTable;
my @bpsOutTable;
my $lowerThres = 1.0;

open(OUT, ">>$outfilename");
open(ASSOC, $filename);
# expected format: Name, bpsOut, bpsIn
while (<ASSOC>) {
	chomp;
	if ($_ =~ /(.+?),(.+?),(.+?)$/) {
		$groupname = $1;	
		$bpsOut = sprintf("%.2f", $2);	
		$bpsIn = sprintf("%.2f", $3);	
		#print $groupname, ",", $bpsOut, ",", $bpsIn, "\n";
		if ($groupname ne '"Name"') {
			if ($bpsOut > $lowerThres) {
				push @bpsOutTable, sprintf("%.2f", $bpsOut);
			}
			if ($bpsIn > $lowerThres) {
				push @bpsInTable, sprintf("%.2f", $bpsIn);
			}
		}
	}		
}
close (ASSOC);

my @sorted_bpsOut = sort { $a <=> $b } @bpsOutTable;
my $OutLen = scalar(@sorted_bpsOut);
my $OutPct95 = int(0.95*$OutLen + 0.5);
my $OutPct98 = int(0.98*$OutLen + 0.5);
#print "debug indices: Len = ", $OutLen, " Pct95 = ", $OutPct95, " Pct98 = ", $OutPct98, "\n";
#print "debug BitsOut Min = ", $sorted_bpsOut[0], " Max = ", $sorted_bpsOut[$OutLen-1], " Pct95 = ", $sorted_bpsOut[$OutPct95-1], "\n";

my @sorted_bpsIn = sort { $a <=> $b } @bpsInTable;
my $InLen = scalar(@sorted_bpsIn);
my $InPct95 = int(0.95*$InLen + 0.5);
my $InPct98 = int(0.98*$InLen + 0.5);
#print "debug indices: Len = ", $InLen, " Pct95 = ", $InPct95, " Pct98 = ", $InPct98, "\n";
#print "debug BitsIn Min = ", $sorted_bpsIn[0], " Max = ", $sorted_bpsIn[$InLen-1], " Pct95 = ", $sorted_bpsIn[$InPct95-1], "\n";
## in wrapping shell script: print 'Exchange List,Ports,Max-In,Max-Out,95%-In,95%-Out,98%-In,98%-Out',"\n";
print OUT $groupname,",",$count,",", $sorted_bpsIn[$InLen-1],",", $sorted_bpsOut[$OutLen-1],",", $sorted_bpsIn[$InPct95-1],",", $sorted_bpsOut[$OutPct95-1],",", $sorted_bpsIn[$InPct98-1],",", $sorted_bpsOut[$OutPct98-1], "\n";
exit;

